==> debug-level-2.0.2.tgz: package/lib/node.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var os = require('os');

var ms = require('ms');

var chalk = require('chalk');

var fastStringify = require('fast-safe-stringify');

var flatstr = require('flatstr');

var _require = require('./utils.js'),
    fromNumLevel = _require.fromNumLevel,
    inspectOpts = _require.inspectOpts,
    saveOpts = _require.saveOpts,
    inspectNamespaces = _require.inspectNamespaces,
    selectColor = _require.selectColor,
    levelColors = _require.levelColors,
    INFO = _require.INFO;

var LogBase = require('./LogBase.js');

var wrapConsole = require('./wrapConsole.js');

var Sonic = require('./Sonic.js');

var errSerializer = require('./serializers/err.js');

var env = process.env.NODE_ENV || 'development';
var isDevEnv = /^dev/.test(env); // anything which starts with dev is seen as development env

var EXIT_EVENTS = ['unhandledRejection', 'uncaughtException'];
/**
 * global log options
 */

var options = {
  level: INFO,
  namespaces: undefined,
  levelNumbers: false,
  json: !isDevEnv,
  // log in json format
  colors: isDevEnv,
  // apply colors
  timestamp: !isDevEnv && 'iso',
  // time format: either `epoch`, `unix`, `iso`
  serverinfo: !isDevEnv,
  // append server information
  stream: process.stderr,
  // output stream
  sonic: !isDevEnv,
  // use Sonic as stream writer
  sonicLength: 4096,
  // buffer length for Sonic
  sonicFlushMs: 1000,
  // min. timeout before write
  spaces: null,
  // pretty print JSON
  splitLine: isDevEnv,
  // split lines for pretty debug like output
  serializers: {
    err: errSerializer
  }
};
/**
 * creates a new logger
 * @constructor
 * @param {String} name - namespace of Logger
 */

function Log(name, opts) {
  if (!(this instanceof Log)) return new Log(name, opts);
  Object.assign(options, inspectOpts(process.env), inspectNamespaces(process.env));
  var serializers = Object.assign({}, options.serializers, opts && opts.serializers);
  LogBase.call(this, name, Object.assign({}, options, opts, {
    serializers: serializers
  }));

  var colorFn = function colorFn(n) {
    return chalk.hex(n);
  };

  this.color = selectColor(name, colorFn);
  this.levColors = levelColors(colorFn);
  this.stream = this.opts.sonic ? new Sonic(this.opts.stream, {
    minLength: this.opts.sonicLength,
    timeout: this.opts.sonicFlushMs
  }) : this.opts.stream;

  if (!this.opts.json) {
    this._log = this._logDebugLike;
  } else if (this.opts.colors) {
    this._log = this._logJsonColor;
  }

  if (this.opts.serverinfo) {
    this.hostname = os.hostname();
    this.pid = process.pid;
  }
}

Object.setPrototypeOf(Log.prototype, LogBase.prototype);
Object.assign(Log.prototype, {
  /**
   * render string to output stream
   * @public
   * @param {String} str - string to render
   * @param {String} level - level of log line (might be used for custom Logger which uses different streams per level)
   * @return {String}
   */
  render: function render(str) {
    this.stream.write(flatstr(str + '\n'));
    return str;
  },
  flush: function flush() {
    this.stream.flush && this.stream.flush();
  },

  /**
   * format object to json
   * @private
   */
  _log: function _log(level, fmt, args) {
    var o = this._formatJson(level, fmt, args);

    var str = toJson(o, this.serializers);
    return this.render(str, level);
  },

  /**
   * format object to json
   * @private
   */
  _logJsonColor: function _logJsonColor(level, fmt, args) {
    var _this = this;

    var o = this._formatJson(level, fmt, args);

    var str = toJson(o, this.serializers);
    /* c8 ignore next 4 */
    // can't cover with tests as underlying tty is unknown

    str = str.replace(/"level":\s?"([^"]+)"/, function (m, level) {
      return _this._color(m, _this.levColors[level], true);
    }).replace(/"level":\s?(\d+)/, function (m, level) {
      return _this._color(m, _this.levColors[fromNumLevel(Number(level))], true);
    }).replace(/"name":\s?"[^"]+"/, function (m) {
      return _this._color(m, _this.color, true);
    });
    return this.render(str, level);
  },

  /**
   * debug like output if `this.opts.json === false`
   * @private
   */
  _logDebugLike: function _logDebugLike(_level, fmt, args) {
    var o = this._formatJson(_level, fmt, args);

    var level = o.level,
        time = o.time,
        name = o.name,
        msg = o.msg,
        pid = o.pid,
        hostname = o.hostname,
        diff = o.diff,
        other = _objectWithoutProperties(o, ["level", "time", "name", "msg", "pid", "hostname", "diff"]);

    var prefix = '  ' + this._color(level, this.levColors[level], true) + ' ' + this._color(this.name, this.color, true);

    var strOther = Object.keys(other).length ? stringify(this._applySerializers(other), this.opts.splitLine && 2) : '';
    var str = this.opts.splitLine ? [prefix, time, msg, strOther, this._color('+' + ms(diff), this.color), hostname, pid].filter(function (s) {
      return s;
    }).join(' ').split(/\\n|\n/).join('\n' + prefix + ' ') : [prefix, time, replaceLf(msg), strOther, this._color('+' + ms(diff), this.color), hostname, pid].filter(function (s) {
      return s;
    }).join(' ');
    return this.render(str, level);
  },

  /**
   * Add colors, style to string
   * @private
   */
  _color: function _color(str, color, isBold) {
    return !this.opts.colors ? str : isBold ? color.bold(str) : color(str);
  }
});
/**
* Apply (and get) global options
* @param {object} [opts] - changed options
* @return {object} global options
*/

Log.options = function (opts) {
  if (!opts) return Object.assign({}, options);
  Object.assign(options, opts);
  return options;
};
/**
 * save options in `process.env`
 */


Log.save = function () {
  Log.reset();
  saveOpts(process.env, options);
};
/**
 * reset saved options
 */


Log.reset = function () {
  Object.keys(process.env).forEach(function (key) {
    if (/^(DEBUG|DEBUG_.*)$/.test(key)) {
      delete process.env[key];
    }
  });
};

Log.isDevEnv = isDevEnv;
/**
 * wrap console logging functions like
 * console.log, console.info, console.warn, console.error
 * @param {string} [name='console']
 * @param {object} opts - see Log.options
 * @param {string} [opts.level4log='log'] - log level for console.log
 * @return {function} unwrap function
 */

Log.wrapConsole = function () {
  var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'console';
  var opts = arguments.length > 1 ? arguments[1] : undefined;
  var log = new Log(name, opts);
  return wrapConsole(log, opts);
};
/**
 * log exit events like 'unhandledRejection', 'uncaughtException'
 * and then let the process die
 * @param {string} [name='exit']
 * @param {object} opts - see Log.options
 * @param {boolean} [opts.code=1] - set exit code; code=0 will prevent triggering exit
 * @param {boolean} [opts.gracefulExit=false] - uses process.exitCode to avoid forceful exit with process.exit()
 */


Log.handleExitEvents = function handleExitEvents() {
  var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'exit';
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var _opts$code = opts.code,
      code = _opts$code === void 0 ? 1 : _opts$code,
      gracefulExit = opts.gracefulExit,
      _opts = _objectWithoutProperties(opts, ["code", "gracefulExit"]);

  var log = new Log(name, _opts);
  EXIT_EVENTS.forEach(function (ev) {
    process.on(ev, function (err) {
      log.fatal(err);
      /* c8 ignore next 7 */

      if (code) {
        if (gracefulExit) {
          process.exitCode = code; // let die...
        } else {
          setTimeout(function () {
            return process.exit(code);
          }, 5);
        }
      }
    });
  });
};

Log.Sonic = Sonic;
module.exports = Log;
/**
 * @credits pino/lib/tools.js
 * magically escape strings for json
 * relying on their charCodeAt
 * everything below 32 needs JSON.stringify()
 * 34 and 92 happens all the time, so we
 * have a fast case for them
 */

function asString(str) {
  var result = '';
  var last = 0;
  var found = false;
  var point = 255;
  var l = str.length;

  if (l > 100) {
    return JSON.stringify(str);
  }

  for (var i = 0; i < l && point >= 32; i++) {
    point = str.charCodeAt(i);

    if (point === 34 || point === 92) {
      result += str.slice(last, i) + '\\';
      last = i;
      found = true;
    }
  }

  if (!found) {
    result = str;
  } else {
    result += str.slice(last);
  }

  return point < 32 ? JSON.stringify(str) : '"' + result + '"';
}

function toJson(obj, serializers, spaces) {
  var s = '{';
  var comma = '';

  for (var key in obj) {
    var value = obj[key];

    if (Object.prototype.hasOwnProperty.call(obj, key) && value !== undefined) {
      if (serializers && serializers[key]) {
        value = serializers[key](value);
      }

      switch (_typeof(value)) {
        case 'function':
          continue;

        case 'number':
          if (!Number.isFinite(value)) {
            continue;
          }

          break;

        case 'boolean':
          break;

        case 'string':
          value = asString(value);
          break;

        default:
          value = stringify(value, spaces);
          break;
      }

      s += comma + asString(key) + ':' + value;
      comma = ',';
    }
  }

  return s + '}';
}

function stringify(any, spaces) {
  try {
    return JSON.stringify(any, null, spaces);
  } catch (e) {
    return fastStringify(any, null, spaces);
  }
}

function replaceLf() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  return str.replace(/[\r\n]/g, '\\n');
}

==> debug-level-2.1.1.tgz: package/lib/node.js <==
"use strict";

var _excluded = ["level", "time", "name", "msg", "pid", "hostname", "diff"],
    _excluded2 = ["code", "gracefulExit"];

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var os = require('os');

var ms = require('ms');

var chalk = require('chalk');

var fastStringify = require('fast-safe-stringify');

var flatstr = require('flatstr');

var _require = require('./utils.js'),
    fromNumLevel = _require.fromNumLevel,
    inspectOpts = _require.inspectOpts,
    saveOpts = _require.saveOpts,
    inspectNamespaces = _require.inspectNamespaces,
    selectColor = _require.selectColor,
    levelColors = _require.levelColors,
    INFO = _require.INFO;

var LogBase = require('./LogBase.js');

var wrapConsole = require('./wrapConsole.js');

var wrapDebug = require('./wrapDebug.js');

var Sonic = require('./Sonic.js');

var errSerializer = require('./serializers/err.js');

var env = process.env.NODE_ENV || 'development';
var isDevEnv = /^dev/.test(env); // anything which starts with dev is seen as development env

var EXIT_EVENTS = ['unhandledRejection', 'uncaughtException'];
/**
 * global log options
 */

var options = {
  level: INFO,
  namespaces: undefined,
  levelNumbers: false,
  json: !isDevEnv,
  // log in json format
  colors: isDevEnv,
  // apply colors
  timestamp: !isDevEnv && 'iso',
  // time format: either `epoch`, `unix`, `iso`
  serverinfo: !isDevEnv,
  // append server information
  stream: process.stderr,
  // output stream
  sonic: !isDevEnv,
  // use Sonic as stream writer
  sonicLength: 4096,
  // buffer length for Sonic
  sonicFlushMs: 1000,
  // min. timeout before write
  spaces: null,
  // pretty print JSON
  splitLine: isDevEnv,
  // split lines for pretty debug like output
  serializers: {
    err: errSerializer
  }
};
/**
 * creates a new logger
 * @constructor
 * @param {String} name - namespace of Logger
 */

function Log(name, opts) {
  if (!(this instanceof Log)) return new Log(name, opts);
  Object.assign(options, inspectOpts(process.env), inspectNamespaces(process.env));
  var serializers = Object.assign({}, options.serializers, opts && opts.serializers);
  LogBase.call(this, name, Object.assign({}, options, opts, {
    serializers: serializers
  }));

  var colorFn = function colorFn(n) {
    return chalk.hex(n);
  };

  this.color = selectColor(name, colorFn);
  this.levColors = levelColors(colorFn);
  this.stream = this.opts.sonic ? new Sonic(this.opts.stream, {
    minLength: this.opts.sonicLength,
    timeout: this.opts.sonicFlushMs
  }) : this.opts.stream;

  if (!this.opts.json) {
    this._log = this._logDebugLike;
  } else if (this.opts.colors) {
    this._log = this._logJsonColor;
  }

  if (this.opts.serverinfo) {
    this.hostname = os.hostname();
    this.pid = process.pid;
  }
}

Object.setPrototypeOf(Log.prototype, LogBase.prototype);
Object.assign(Log.prototype, {
  /**
   * render string to output stream
   * @public
   * @param {String} str - string to render
   * @param {String} level - level of log line (might be used for custom Logger which uses different streams per level)
   * @return {String}
   */
  render: function render(str) {
    this.stream.write(flatstr(str + '\n'));
    return str;
  },
  flush: function flush() {
    this.stream.flush && this.stream.flush();
  },

  /**
   * format object to json
   * @private
   */
  _log: function _log(level, fmt, args) {
    var o = this._formatJson(level, fmt, args);

    var str = toJson(o, this.serializers);
    return this.render(str, level);
  },

  /**
   * format object to json
   * @private
   */
  _logJsonColor: function _logJsonColor(level, fmt, args) {
    var _this = this;

    var o = this._formatJson(level, fmt, args);

    var str = toJson(o, this.serializers);
    /* c8 ignore next 4 */
    // can't cover with tests as underlying tty is unknown

    str = str.replace(/"level":\s?"([^"]+)"/, function (m, level) {
      return _this._color(m, _this.levColors[level], true);
    }).replace(/"level":\s?(\d+)/, function (m, level) {
      return _this._color(m, _this.levColors[fromNumLevel(Number(level))], true);
    }).replace(/"name":\s?"[^"]+"/, function (m) {
      return _this._color(m, _this.color, true);
    });
    return this.render(str, level);
  },

  /**
   * debug like output if `this.opts.json === false`
   * @private
   */
  _logDebugLike: function _logDebugLike(_level, fmt, args) {
    var o = this._formatJson(_level, fmt, args);

    var level = o.level,
        time = o.time,
        name = o.name,
        msg = o.msg,
        pid = o.pid,
        hostname = o.hostname,
        diff = o.diff,
        other = _objectWithoutProperties(o, _excluded);

    var prefix = '  ' + this._color(level, this.levColors[level], true) + ' ' + this._color(this.name, this.color, true);

    var strOther = Object.keys(other).length ? stringify(this._applySerializers(other), this.opts.splitLine && 2) : '';
    var str = this.opts.splitLine ? [prefix, time, msg, strOther, this._color('+' + ms(diff), this.color), hostname, pid].filter(function (s) {
      return s;
    }).join(' ').split(/\\n|\n/).join('\n' + prefix + ' ') : [prefix, time, replaceLf(msg), strOther, this._color('+' + ms(diff), this.color), hostname, pid].filter(function (s) {
      return s;
    }).join(' ');
    return this.render(str, level);
  },

  /**
   * Add colors, style to string
   * @private
   */
  _color: function _color(str, color, isBold) {
    return !this.opts.colors ? str : isBold ? color.bold(str) : color(str);
  }
});
/**
* Apply (and get) global options
* @param {object} [opts] - changed options
* @return {object} global options
*/

Log.options = function (opts) {
  if (!opts) return Object.assign({}, options);
  Object.assign(options, opts);
  return options;
};
/**
 * save options in `process.env`
 */


Log.save = function () {
  Log.reset();
  saveOpts(process.env, options);
};
/**
 * reset saved options
 */


Log.reset = function () {
  Object.keys(process.env).forEach(function (key) {
    if (/^(DEBUG|DEBUG_.*)$/.test(key)) {
      delete process.env[key];
    }
  });
};

Log.isDevEnv = isDevEnv;
/**
 * wrap console logging functions like
 * console.log, console.info, console.warn, console.error
 * @param {string} [name='console']
 * @param {object} opts - see Log.options
 * @param {string} [opts.level4log='log'] - log level for console.log
 * @return {function} unwrap function
 */

Log.wrapConsole = function () {
  var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'console';
  var opts = arguments.length > 1 ? arguments[1] : undefined;
  var log = new Log(name, opts);
  return wrapConsole(log, opts);
};
/**
 * log exit events like 'unhandledRejection', 'uncaughtException'
 * and then let the process die
 * @param {string} [name='exit']
 * @param {object} opts - see Log.options
 * @param {boolean} [opts.code=1] - set exit code; code=0 will prevent triggering exit
 * @param {boolean} [opts.gracefulExit=false] - uses process.exitCode to avoid forceful exit with process.exit()
 */


Log.handleExitEvents = function handleExitEvents() {
  var name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'exit';
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var _opts$code = opts.code,
      code = _opts$code === void 0 ? 1 : _opts$code,
      gracefulExit = opts.gracefulExit,
      _opts = _objectWithoutProperties(opts, _excluded2);

  var log = new Log(name, _opts);
  EXIT_EVENTS.forEach(function (ev) {
    process.on(ev, function (err) {
      log.fatal(err);
      /* c8 ignore next 7 */

      if (code) {
        if (gracefulExit) {
          process.exitCode = code; // let die...
        } else {
          setTimeout(function () {
            return process.exit(code);
          }, 5);
        }
      }
    });
  });
};

Log.wrapDebug = function () {
  return wrapDebug(Log);
};

Log.Sonic = Sonic;
module.exports = Log;
/**
 * @credits pino/lib/tools.js
 * magically escape strings for json
 * relying on their charCodeAt
 * everything below 32 needs JSON.stringify()
 * 34 and 92 happens all the time, so we
 * have a fast case for them
 */

function asString(str) {
  var result = '';
  var last = 0;
  var found = false;
  var point = 255;
  var l = str.length;

  if (l > 100) {
    return JSON.stringify(str);
  }

  for (var i = 0; i < l && point >= 32; i++) {
    point = str.charCodeAt(i);

    if (point === 34 || point === 92) {
      result += str.slice(last, i) + '\\';
      last = i;
      found = true;
    }
  }

  if (!found) {
    result = str;
  } else {
    result += str.slice(last);
  }

  return point < 32 ? JSON.stringify(str) : '"' + result + '"';
}

function toJson(obj, serializers, spaces) {
  var s = '{';
  var comma = '';

  for (var key in obj) {
    var value = obj[key];

    if (Object.prototype.hasOwnProperty.call(obj, key) && value !== undefined) {
      if (serializers && serializers[key]) {
        value = serializers[key](value);
      }

      switch (_typeof(value)) {
        case 'function':
          continue;

        case 'number':
          if (!Number.isFinite(value)) {
            continue;
          }

          break;

        case 'boolean':
          break;

        case 'string':
          value = asString(value);
          break;

        default:
          value = stringify(value, spaces);
          break;
      }

      s += comma + asString(key) + ':' + value;
      comma = ',';
    }
  }

  return s + '}';
}

function stringify(any, spaces) {
  try {
    return JSON.stringify(any, null, spaces);
  } catch (e) {
    return fastStringify(any, null, spaces);
  }
}

function replaceLf() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  return str.replace(/[\r\n]/g, '\\n');
}
